Xqt has submitted this change. ( 
https://gerrit.wikimedia.org/r/c/pywikibot/core/+/773920 )

Change subject: [cleanup] Deprecate win32_unicode
......................................................................

[cleanup] Deprecate win32_unicode

Change-Id: I6dcbe9d216e088008799d7f87ef67f9f71eb6f24
---
M ROADMAP.rst
M pywikibot/userinterfaces/win32_unicode.py
2 files changed, 6 insertions(+), 2 deletions(-)

Approvals:
  Xqt: Verified; Looks good to me, approved



diff --git a/ROADMAP.rst b/ROADMAP.rst
index ca68e8c..d19c3bf 100644
--- a/ROADMAP.rst
+++ b/ROADMAP.rst
@@ -7,6 +7,7 @@
 Deprecations
 ^^^^^^^^^^^^

+* 7.1.0: win32_unicode.py will be removed with Pywikibot 8
 * 7.1.0: Unused `get_redirect` parameter of Page.getOldVersion() will be 
removed
 * 7.1.0: APISite._simple_request() will be removed in favour of 
APISite.simple_request()
 * 7.0.0: The i18n identifier 'cosmetic_changes-append' will be removed in 
favour of 'pywikibot-cosmetic-changes'
@@ -30,4 +31,3 @@
 * 5.5.0: APISite.redirectRegex() is deprecated in favour of 
APISite.redirect_regex()
 * 4.0.0: Revision.parent_id is deprecated in favour of Revision.parentid
 * 4.0.0: Revision.content_model is deprecated in favour of 
Revision.contentmodel
-
diff --git a/pywikibot/userinterfaces/win32_unicode.py 
b/pywikibot/userinterfaces/win32_unicode.py
index 75008a4..a135878 100644
--- a/pywikibot/userinterfaces/win32_unicode.py
+++ b/pywikibot/userinterfaces/win32_unicode.py
@@ -1,4 +1,8 @@
-"""Stdout, stderr and argv support for unicode."""
+"""Unicode support for stdout, stderr and argv with Python 3.5.
+
+.. deprecated:: 7.1
+   will be removed with Pywikibot 8 when Python 3.5 support is dropped.
+"""
 #
 # (C) Pywikibot team, 2012-2022
 #

--
To view, visit https://gerrit.wikimedia.org/r/c/pywikibot/core/+/773920
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.wikimedia.org/r/settings

Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-Change-Id: I6dcbe9d216e088008799d7f87ef67f9f71eb6f24
Gerrit-Change-Number: 773920
Gerrit-PatchSet: 1
Gerrit-Owner: Xqt <[email protected]>
Gerrit-Reviewer: Xqt <[email protected]>
Gerrit-Reviewer: jenkins-bot
Gerrit-MessageType: merged
_______________________________________________
Pywikibot-commits mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to